@@ -152,6 +152,17 @@ class BookmarkModelView(BaseModelView):
         self.url_render_mode = kwargs.pop('url_render_mode', DEFAULT_URL_RENDER_MODE)
         super().__init__(*args, **kwargs)
 
+    def create_form(self, obj=None):
+        form = super().create_form(obj)
+        args = request.args
+        if 'url' in args.keys() and not args.get("url").startswith('/bookmark/'):
+            form.url.data = args.get("url")
+        if 'title' in args.keys():
+            form.title.data = args.get("title")
+        if 'description' in args.keys():
+            form.description.data = args.get("description")
+        return form
+
     def create_model(self, form):
         try:
             model = SimpleNamespace(id=None, url=None, title=None, tags=None, description=None)
@@ -209,7 +220,10 @@ class BookmarkModelView(BaseModelView):
             bookmarks = sorted(bookmarks, key=lambda x: x[key_idx], reverse=sort_desc)
         count = len(bookmarks)
         if page_size and bookmarks:
-            bookmarks = list(chunks(bookmarks, page_size))[page]
+            try:
+                bookmarks = list(chunks(bookmarks, page_size))[page]
+            except IndexError:
+                bookmarks = []
         data = []
         for bookmark in bookmarks:
             bm_sns = SimpleNamespace(id=None, url=None, title=None, tags=None, description=None)
